@@ -12,8 +12,6 @@
 #'
 #' @seealso \code{\link{bquote_function}}, \code{\link{bquote_call_args}}
 #'
-#' @keywords internal
-#'
 #'
 #' @export
 #'
@@ -84,6 +82,8 @@ bquote_call <- function(call, env = parent.frame()) {
 #'
 #' print(args)
 #'
+#' @keywords internal
+#'
 #' @export
 #'
 #'
@@ -102,6 +102,8 @@ bquote_call_args <- function(call, env = parent.frame()) {
 }
 
 
+#' @importFrom graphics plot
+NULL
 
 
 #' Adapt a function to use bquote on its arguments.
@@ -115,12 +117,24 @@ bquote_call_args <- function(call, env = parent.frame()) {
 #'
 #' @examples
 #'
+#'
+#'
+#' angle = 1:10
+#' variable <- as.name("angle")
+#' plotb <- bquote_function(graphics::plot)
+#' plotb(x = .(variable), y = sin(.(variable)))
+#'
+#'
+#'
 #' f1 <- function(x) { substitute(x) }
 #' f2 <- bquote_function(f1)
 #' arg <- as.name("USER_ARG")
 #' f2(arg)    # returns arg
 #' f2(.(arg)) # returns USER_ARG
 #'
+#'
+#'
+#'
 #' @export
 #'
 bquote_function <- function(fn) {
@@ -151,9 +165,9 @@ bquote_function <- function(fn) {
 #'
 #' @examples
 #'
-#' x = 5
-#' y = 2
-#' evalb(.(x) + .(y))
+#' angle = 1:10
+#' variable <- as.name("angle")
+#' evalb(plot(x = .(variable), y = sin(.(variable))))
 #'
 #' @export
 #'
