@@ -14,9 +14,10 @@ test_that("test_coalesce.R", {
   expect_equal(list(1, NULL, NULL, NA, NA) %?% list(2, NULL, NA, NULL, NA) , list(1, NULL, NA, NULL, NA))
   expect_equal(c(1, NA, NA) %?% list(1, 2, list(3)) , c(1, 2, NA))
   expect_equal(c(1, NA) %?% list(1, NULL)           , c(1, NA))
-  expect_error(list() %?% list(1, NA, NULL))
+  expect_equal(list() %?% list(1, NA, NULL), list(1, NA, NULL) )
   expect_equal(c() %?% list(1, NA, NULL)    , list(1, NA, NULL) )
   expect_equal(c() %?% c(1, NA, 2)          , c(1, NA, 2))
   expect_equal(c(a=1, b= NA) %?% list(3,4), c(a=1, b=4))
   expect_equal(list(a=1, b= NA) %?% c(3,4), list(a=1, b=4))
+  expect_equal(NULL %?% 4, 4)
 })
